Core Library — ATLAS 0.1 documentation

# Core Library

The library that does the actual execution.

reverse(...)

  Returns the reverse of the argument.

  Parameters

    data (any) – The data to be reversed.

  Returns

    Reversed data.

download_from_remote_server(...)

  Downloads from the server that is passed as a argument.

  Parameters

    addr (str) – Address of the server.

  Returns

    Bytes object of the response.

powershell_executor(...)

  Executes the powershell script that is passed as a argument.

  Parameters

    - script_name (tuple) – Tuple object, script’s name and base64 encoded content. It is enough to pass script key.

    - *args (any) –

      Arguments to pass corresponding script.

  Returns

    Return data of the execution.

file_read_bin(...)

  Performs binary file read operation.

  Parameters

    path (str) – File’s path.

  Returns

    Bytes object of the file’s content.

save_file_bytes(...)

  Performs binary file write operation.

  Parameters

    - data (any) – Content to save.

    - prefix (str) – File’s name prefix.

  Returns

    Bool, condition of the operation.

save_file_arr(...)

  Performs file write one by one according to the list type argument.

  Parameters

    - arr (list) – List of contents to save.

    - prefix (str) – File’s name prefix. Default value is ‘output’.

  Returns

    Bool, condition of the operation.

python_executor(...)

  Executes the python script that is passed as an argument.

  Parameters

    - script_name (tuple) – Tuple object, script’s name and base64 encoded content. It is enough to pass script key.

    - *args (any) –

      Arguments to pass corresponding script.

  Returns

    Return data of the execution.

printer(...)

  Prints the arguments by joining them.

  Parameters

    *args (any) –

    Strings to print.

  Returns

    Bool, condition of the operation.

hello_world(...)

  Prints “Hello World, ATLAS.” string. Can be used as a test.

  Returns

    None.